@@ -130,7 +130,9 @@ sub add_page_header {
 	$self->page->header(Khonsu::Page::Header->new(
 		%args
 	));
-
+	if ($self->page->y < $self->page->header->h) {
+		$self->page->column_y($self->page->y($self->page->header->h));
+	}
 	return $self;
 }
 
